/**
 * Kivu4j. Copyright (C) 2010 . see<http://kivu4j.sourceforge.net />

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses />.
 */

package net.sourceforge.kivu4j.utils.lang.domain;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

/**
 * 泛型实体类
 * 
 *
 * @author Lucky Yang
 */
public abstract class BaseEntity<PK extends Serializable> implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = -4627040124088330247L;
	private PK ID;
	private Integer version;
	private Date createOn;
	private Date modifyOn;	
	
	public PK getID() {
		return ID;
	}

	public void setID(PK iD) {
		ID = iD;
	}

	public Integer getVersion() {
		return version;
	}

	public void setVersion(Integer version) {
		this.version = version;
	}

	public boolean isNew() {
		return ! this.isPersist();
	}

	public boolean isPersist() {
		return (this.ID != null);
	}

	public Date getCreateOn() {
		return createOn;
	}

	public void setCreateOn(Date createOn) {
		this.createOn = createOn;
	}

	public Date getModifyOn() {
		return modifyOn;
	}

	public void setModifyOn(Date modifyOn) {
		this.modifyOn = modifyOn;
	}

	public Date getRealModifyOn(){
		return this.modifyOn == null?this.createOn:this.modifyOn;
	}
	
	@Override
    public boolean equals(Object other) {
    	if (this == other) return true;
    	if (!(other instanceof BaseEntity<?>)) return false;
    	
    	@SuppressWarnings("rawtypes")
		BaseEntity castOther = (BaseEntity) other;
        return new EqualsBuilder()
            .append(this.ID, castOther.ID)
            .isEquals();
    }

	@Override
    public int hashCode() {
        return new HashCodeBuilder()
            .append(this.ID)
            .toHashCode();
    }
	
	
	@Override
	public String toString() {
		return new StringBuilder()
			.append("id=" +  this.getID())
			.append(",version=" +  this.getVersion())
			.append(",createOn=" +  this.getCreateOn())
			.append(",modifyOn=" +  this.getModifyOn())
			.toString();
	}	
}
