/**
 * Kivu4j. Copyright (C) 2010 . see<http://kivu4j.sourceforge.net />

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses />.
 */

package net.sourceforge.kivu4j.utils.lang.domain;

import java.sql.Date;

import net.sourceforge.kivu4j.utils.lang.ConvertUtil;

import org.apache.commons.lang.builder.ToStringBuilder;


/**
 * 过滤条件类
 *
 * @author Lucky Yang
 */
public class Filter {
	public enum TYPE
	{
	    NUMERIC, STRING, BOOLEAN, DATE, FLOAT,LIST,INTEGER; 
	}
	
	public enum COMPARISON
	{
	    EQ, LT, GT, IN, LIKE; 
	}
	
	public enum DIR
	{
		ASC,DESC
	}
	
	private String type;
	private String comparison;
	private Object value;
	private String field;
	private String component;
	private String alias;
	private String dir;
	
	public Filter() {
		super();
	}

	public Filter(
			String type
			, String comparison
			, Object value
			, String field) {
		super();
		this.type = type;
		this.comparison = comparison;
		this.value = value;
		this.field = field;
	}

	public Filter(
			String type
			, String comparison
			, Object value
			, String field
			, String component
			, String alias) {
		this(type, comparison, value, field);
		this.component = component;
		this.alias = alias;
	}

	public String getAlias() {
		return alias;
	}

	public void setAlias(String alias) {
		this.alias = alias;
	}

	public String getType() {
		return type;
	}
	public void setType(String type) {
		this.type = type;
	}
	public void setType(TYPE t) {
		this.type = t.name();
	}
	public String getComparison() {
		return comparison;
	}

	public void setComparison(String comparison) {
		this.comparison = comparison;
	}
	
	public void setComparison(COMPARISON c) {
		this.comparison = c.name();		
	}
	
	public Object getValue() {
		return value;
	}
	public void setValue(Object value) {
		this.value = value;
	}
	public String getField() {
		return field;
	}
	public void setField(String field) {
		this.field = field;
	}

	public String getComponent() {
		return component;
	}

	public void setComponent(String component) {
		this.component = component;
	}

	public String getDir() {
		return dir;
	}

	public void setDir(String dir) {
		this.dir = dir;
	}
	
	public void setDir(DIR d){ 
		this.dir = d.name();
	}
	
	//
	public String getRealColumnName(){
		return this.component == null? this.field: this.component + "." + this.field;
	}
	
	public Object getRealValue(){
		Object rslt = null;
		try{
			switch (TYPE.valueOf(this.type.toUpperCase())){
				case NUMERIC: 
					rslt = ConvertUtil.convert(value, Long.class);
					break;
				case INTEGER: 
					rslt = ConvertUtil.convert(value, Integer.class);
					break;					
				case STRING:
					rslt = ConvertUtil.convert(value, String.class);
					break;	
				case BOOLEAN:
					rslt = ConvertUtil.convert(value, Boolean.class);
					break;	
				case DATE:
					rslt = ConvertUtil.convert(value, Date.class);
					break;	
				case FLOAT:
					rslt = ConvertUtil.convert(value, Double.class);
					break;
				case LIST:
					rslt = ConvertUtil.arrayOf(ConvertUtil.convert(value, String.class), ",", Integer.class);					
					break;			
			}
		}catch(IllegalArgumentException e){
			throw new FilterTypeNotSupportException(this.type);
		}
		
		return rslt;
	}

	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
	
	
}