/**
 * Kivu4j. Copyright (C) 2010 . see<http://kivu4j.sourceforge.net />

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses />.
 */

package net.sourceforge.kivu4j.utils.lang.domain;

import java.io.Serializable;

/**
 * 密码类
 * 
 *
 * @author Lucky Yang
 */
public class Password implements Serializable{
	/**
	 * 
	 */
	private static final long serialVersionUID = -2317181698007980074L;
	public static final String ENCRYPTION_PREFIX = "{encrypt}";
	private String password;

	public Password(String password) {
		super();
		this.password = password;
	}
	
	public Password() {
		super();
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * 密码校验，大小写无关。
	 * </p>
	 * Password validated，equals ignore case
	 * 
	 * @param password 
	 * @return
	 */
	public boolean isValid(Password dest) {
		return (dest == null || dest.password == null)? 
				false: dest.password.equalsIgnoreCase(this.password);
	}
	
	/**
	 * 密码是否加密。
	 * </p>
	 * Whether encryption password or not
	 * 
	 * @param password 
	 * @return
	 */	
	public boolean isEncrypted(){
		if (password == null) return true;
		
		return this.password.startsWith(ENCRYPTION_PREFIX);
	}
	
	public boolean isNOTEncrypted(){
		return !this.isEncrypted();
	}	
}
